#include "base/base.h"
namespace mozc {
namespace {
class POSMatcher {
 public:
  // Functional "^(助詞|助動詞|動詞,非自立|名詞,非自立|形容詞,非自立|動詞,接尾|名詞,接尾|形容詞,接尾)"
  static uint16 GetFunctionalId() {
    return 42;
  }
  static bool IsFunctional(uint16 id) {
    return ((id >= 42 && id <= 603) || (id >= 1082 && id <= 1931) || (id >= 2015 && id <= 2039) || (id >= 2053 && id <= 2279) || (id >= 2549 && id <= 2661));
  }
  // Unknown "名詞,サ変接続"
  static uint16 GetUnknownId() {
    return 1932;
  }
  static bool IsUnknown(uint16 id) {
    return ((id >= 1932 && id <= 1935));
  }
  // FirstName "名詞,固有名詞,人名,名"
  static uint16 GetFirstNameId() {
    return 2005;
  }
  static bool IsFirstName(uint16 id) {
    return ((id == 2005));
  }
  // LastName "名詞,固有名詞,人名,姓"
  static uint16 GetLastNameId() {
    return 2006;
  }
  static bool IsLastName(uint16 id) {
    return ((id == 2006));
  }
  // Number "名詞,数,アラビア数字"
  static uint16 GetNumberId() {
    return 2042;
  }
  static bool IsNumber(uint16 id) {
    return ((id == 2042));
  }
  // KanjiNumber "名詞,数,漢数字"
  static uint16 GetKanjiNumberId() {
    return 2044;
  }
  static bool IsKanjiNumber(uint16 id) {
    return ((id >= 2044 && id <= 2051));
  }
  // WeakCompoundPrefix "^(接頭詞,名詞接続|接頭詞,丁寧連用形接続|フィラー)"
  static uint16 GetWeakCompoundPrefixId() {
    return 2;
  }
  static bool IsWeakCompoundPrefix(uint16 id) {
    return ((id >= 2 && id <= 11) || (id == 2664) || (id >= 2666 && id <= 2695));
  }
  // AcceptableParticleAtBeginOfSegment "^助詞,*,*,*,*,*,(が|で|と|に|にて|の|へ|より|も|と|から|は|や)$"
  static uint16 GetAcceptableParticleAtBeginOfSegmentId() {
    return 287;
  }
  static bool IsAcceptableParticleAtBeginOfSegment(uint16 id) {
    return ((id == 287) || (id == 290) || (id >= 299 && id <= 301) || (id >= 342 && id <= 343) || (id == 346) || (id == 348) || (id >= 362 && id <= 363) || (id == 376) || (id >= 380 && id <= 388) || (id == 391) || (id == 400) || (id == 402) || (id == 412) || (id == 431) || (id == 447) || (id == 453) || (id == 469));
  }
  // JapanesePunctuations "記号,(句点|読点)"
  static uint16 GetJapanesePunctuationsId() {
    return 2700;
  }
  static bool IsJapanesePunctuations(uint16 id) {
    return ((id == 2700) || (id == 2703));
  }
  // OpenBracket "記号,括弧開"
  static uint16 GetOpenBracketId() {
    return 2702;
  }
  static bool IsOpenBracket(uint16 id) {
    return ((id == 2702));
  }
  // CloseBracket "記号,括弧閉"
  static uint16 GetCloseBracketId() {
    return 2701;
  }
  static bool IsCloseBracket(uint16 id) {
    return ((id == 2701));
  }
  // Zipcode "特殊,郵便番号"
  static uint16 GetZipcodeId() {
    return 2717;
  }
  static bool IsZipcode(uint16 id) {
    return ((id == 2717));
  }
  // IsolatedWord "特殊,短縮よみ"
  static uint16 GetIsolatedWordId() {
    return 2718;
  }
  static bool IsIsolatedWord(uint16 id) {
    return ((id == 2718));
  }
  // SuggestOnlyWord "特殊,サジェストのみ"
  static uint16 GetSuggestOnlyWordId() {
    return 2719;
  }
  static bool IsSuggestOnlyWord(uint16 id) {
    return ((id == 2719));
  }
  // ContentWordWithConjugation "^(動詞,自立,*,*,五段|動詞,自立,*,*,一段|形容詞,自立)"
  static uint16 GetContentWordWithConjugationId() {
    return 719;
  }
  static bool IsContentWordWithConjugation(uint16 id) {
    return ((id >= 719 && id <= 1039) || (id >= 2280 && id <= 2548));
  }
 private:
  POSMatcher() {}
  ~POSMatcher() {}
};
}  // namespace
}  // mozc
